Generic | Progressive Accessibility Solutions
Keywords: progressive,accessibility,solutions,stem,chemistry,mathematics,education

Key | Action
--- | ---
Enter, A | Activate keyboard driven exploration
B | Activate menu driven exploration
Escape | Leave exploration mode
Cursor down | Explore next lower level
Cursor up | Explore next upper level
Cursor right | Explore next element on level
Cursor left | Explore previous element on level
X | Toggle expert mode
W | Extra details if available
Space | Repeat speech
M | Activate step magnification
Comma | Activate direct magnification
N | Deactivate magnification
Z | Toggle subtitles
C | Cycle contrast settings
T | Monochrome colours
L | Toggle language (if available)
K | Kill current sound
Y | Stop sound output
O | Start and stop sonification
P | Repeat sonification output